==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/da/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Denne bruger kan logge ind',
    'activated_disabled_help_text' => 'Du kan ikke redigere rettigheder for din egen konto.',
    'assets_user'       => 'Aktiver tildelt :navn',
    'bulk_update_warn'	=> 'Du er ved at redigere egenskaberne for: user_count-brugere. Bemærk, at du ikke kan ændre dine egne brugerattributter ved hjælp af denne formular, og skal foretage ændringer til din egen bruger individuelt.',
    'bulk_update_help'	=> 'Denne formular giver dig mulighed for at opdatere flere brugere på én gang. Udfyld kun de felter, du skal ændre. Alle felter, der er tomt, forbliver uændrede.',
    'current_assets'    => 'Aktier tjekket ud for denne bruger',
    'clone'             => 'Klon bruger',
    'contact_user'      => 'Kontakt :navn',
    'edit'              => 'Redigér bruger',
    'filetype_info'     => 'Tilladte filtyper er png, gif, jpg, jpeg, doc, docx, pdf, txt, zip og rar.',
    'history_user'      => 'Historie for: navn',
	'info'				=> 'Information',
    'restore_user'		=> 'Klik her for at gendanne dem.',
    'last_login'        => 'Sidste Login',
    'ldap_config_text'  => 'LDAP-konfigurationsindstillinger kan findes Admin> Indstillinger. Den (valgfrie) valgte placering vil blive indstillet for alle importerede brugere.',
    'print_assigned'    => 'Udskriv alle tildelte',
    'software_user'     => 'Software Checket ud til: navn',
    'send_email_help'   => 'Du skal angive en e-mail-adresse for denne bruger for at sende dem legitimationsoplysninger. E-mailing af legitimationsoplysninger kan kun gøres ved brugeroprettelse. Adgangskoder gemmes i en envejs hash og kan ikke hentes når de er gemt.',
    'view_user'         => 'Se bruger :navn',
    'usercsv'           => 'CSV-fil',
    'two_factor_admin_optin_help' => 'Dine nuværende administratorindstillinger tillader selektiv håndhævelse af tofaktors godkendelse.',
    'two_factor_enrolled' => '2FA Device Enrolled',
    'two_factor_active'   => '2FA aktiv ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/da/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Denne bruger kan logge ind',
    'activated_disabled_help_text' => 'Du kan ikke redigere rettigheder for din egen konto.',
    'assets_user'       => 'Aktiver tildelt :navn',
    'bulk_update_warn'	=> 'Du er ved at redigere egenskaberne for: user_count-brugere. Bemærk, at du ikke kan ændre dine egne brugerattributter ved hjælp af denne formular, og skal foretage ændringer til din egen bruger individuelt.',
    'bulk_update_help'	=> 'Denne formular giver dig mulighed for at opdatere flere brugere på én gang. Udfyld kun de felter, du skal ændre. Alle felter, der er tomt, forbliver uændrede.',
    'current_assets'    => 'Aktier tjekket ud for denne bruger',
    'clone'             => 'Klon bruger',
    'contact_user'      => 'Kontakt :navn',
    'edit'              => 'Redigér bruger',
    'filetype_info'     => 'Tilladte filtyper er png, gif, jpg, jpeg, doc, docx, pdf, txt, zip og rar.',
    'history_user'      => 'Historie for: navn',
    'info'				=> 'Information',
    'restore_user'		=> 'Klik her for at gendanne dem.',
    'last_login'        => 'Sidste Login',
    'ldap_config_text'  => 'LDAP-konfigurationsindstillinger kan findes Admin> Indstillinger. Den (valgfrie) valgte placering vil blive indstillet for alle importerede brugere.',
    'print_assigned'    => 'Udskriv alle tildelte',
    'software_user'     => 'Software Checket ud til: navn',
    'send_email_help'   => 'Du skal angive en e-mail-adresse for denne bruger for at sende dem legitimationsoplysninger. E-mailing af legitimationsoplysninger kan kun gøres ved brugeroprettelse. Adgangskoder gemmes i en envejs hash og kan ikke hentes når de er gemt.',
    'view_user'         => 'Se bruger :navn',
    'usercsv'           => 'CSV-fil',
    'two_factor_admin_optin_help' => 'Dine nuværende administratorindstillinger tillader selektiv håndhævelse af tofaktors godkendelse.',
    'two_factor_enrolled' => '2FA Device Enrolled',
    'two_factor_active'   => '2FA aktiv ',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
